@@ -1,5 +1,7 @@
 from simpleMediaCenter.interface.Interface import Interface, ExceptionDisplayHandler
 from simpleMediaCenter.helpers.twitch import TwitchException
+import simpleMediaCenter.interface.service as service
+
 from tg import expose, TGController, AppConfig, redirect, config
 from wsgiref.simple_server import make_server, WSGIServer
 from socketserver import ThreadingMixIn
@@ -7,39 +9,39 @@ import os
 import jinja2
 import logging
 import json
+import threading
 
 class WebController(TGController):  
     __logger=logging.getLogger(__name__)
-    playerList=None
-    playlistList=None
-    browserList=None
     statusDict=None
     exceptionDisplayHandler=None
+    thread=None
 
-    def __init__(self, playerList=None, playlistList=None, browserList=None ):
+    def __init__(self):
         self.__logger.debug("WebInterface init")
-        self.playerList=playerList
-        self.browserList=browserList
-        self.playlistList=playlistList
         self.exceptionDisplayHandler=ExceptionDisplayHandler()
         self.statusDict = {
-            'playerArray'  : self.playerList.getArray(),
-            'playlistArray'  : self.playlistList.getArray(),
-            'browserArray'  : self.browserList.getArray(),
+            'playerArray'  : service.playerList.getArray(),
+            'playlistArray'  : service.playlistList.getArray(),
+            'browserArray'  : service.browserList.getArray(),
+            'threadRunning' : 0
             }
             
     def updateStatus(self):
         self.__logger.debug("updateStatus")
-        if(self.playerList.getActive() is not None):
-            self.statusDict.update(self.playerList.getActive().getDict())
-        if(self.playlistList.getActive() is not None):
-            self.statusDict.update(self.playlistList.getActive().getDict())
-        if(self.browserList.getActive() is not None):
-            self.statusDict.update(self.browserList.getActive().getDict())
+        if(service.playerList.getActive() is not None):
+            self.statusDict.update(service.playerList.getActive().getDict())
+        if(service.playlistList.getActive() is not None):
+            self.statusDict.update(service.playlistList.getActive().getDict())
+        if(service.browserList.getActive() is not None):
+            self.statusDict.update(service.browserList.getActive().getDict())
         if(self.exceptionDisplayHandler is not None):
             self.statusDict.update(self.exceptionDisplayHandler.getDict())
-            
-        
+        if(self.thread!=None):
+            self.statusDict['threadRunning'] = 1
+        else:
+            self.statusDict['threadRunning'] = 0
+    
     def parseID(self, id):
         id = int(id)
         return id
@@ -48,6 +50,9 @@ class WebController(TGController):
     @expose('index.html')
     def index(self):
         self.__logger.debug('index called')
+        if(self.thread!=None): #wait for thread before building page
+            self.thread.join()
+            self.thread=None
         self.updateStatus()
         self.__logger.debug(self.statusDict)
         return self.statusDict
@@ -58,8 +63,7 @@ class WebController(TGController):
     def loading(self):
         self.__logger.debug('loading called')
         redirect("/")
-    '''    
-        
+    '''
     
     #controls
     '''
@@ -69,20 +73,12 @@ class WebController(TGController):
     def play(self, id=None):
         try:
             id = self.parseID(id)
-            self.__logger.debug("trying to play %s" ,self.browserList.getActive().getPlayable(id))
-            self.__logger.debug("searching for compatible Browser") 
-            for supportedPlayer in self.browserList.getActive().getSupportedPlayers():
-                playerid = self.playerList.getIDfromName(supportedPlayer)
-                if (playerid is not None):
-                    break
-            if (playerid is None):
-                raise Exception('no compatible player found in supportedPlayers')
-            self.playerList.getActive().stop()
-            self.playerList.setActive(playerid)
-            self.playerList.getActive().play(self.browserList.getActive().getPlayable(id))
+            self.thread = threading.Thread(target=service.play,args=(id,))
+            self.thread.start()
         except Exception as e:
-            self.exceptionDisplayHandler.setException('Exception','Unhandled Exception in play: ' + repr(e))
-
+            self.exceptionDisplayHandler.setException(
+                'Exception',
+                'Unhandled Exception in play: ' + repr(e))
         redirect("/")
     
     '''
@@ -90,8 +86,12 @@ class WebController(TGController):
     '''
     @expose()
     def stop(self):
-        self.__logger.debug("stop called")
-        self.playerList.getActive().stop()
+        try:
+            service.stop()
+        except Exception as e:
+            self.exceptionDisplayHandler.setException(
+                'Exception',
+                'Unhandled Exception in stop: ' + repr(e))
         redirect("/")
       
     '''
@@ -99,8 +99,12 @@ class WebController(TGController):
     '''
     @expose()
     def pause(self):
-        self.__logger.debug("pause called")
-        self.playerList.getActive().pause()
+        try:
+            service.pause()
+        except Exception as e:
+            self.exceptionDisplayHandler.setException(
+                'Exception',
+                'Unhandled Exception in pause: ' + repr(e))
         redirect("/")
         
     '''
@@ -108,8 +112,12 @@ class WebController(TGController):
     '''
     @expose()
     def volumedown(self):
-        self.__logger.debug("volume down called")
-        self.playerList.getActive().volumeDown()
+        try:
+            service.volume_down()
+        except Exception as e:
+            self.exceptionDisplayHandler.setException(
+                'Exception',
+                'Unhandled Exception in volumedown: ' + repr(e))
         redirect("/")
         
     '''
@@ -117,8 +125,12 @@ class WebController(TGController):
     '''
     @expose()
     def volumeup(self):
-        self.__logger.debug("volume up called")
-        self.playerList.getActive().volumeUp()
+        try:
+            service.volume_up()
+        except Exception as e:
+            self.exceptionDisplayHandler.setException(
+                'Exception',
+                'Unhandled Exception in volumeup: ' + repr(e))
         redirect("/")
         
     '''
@@ -128,8 +140,8 @@ class WebController(TGController):
     def change(self,id=None):
         try:
             id = self.parseID(id)
-            self.__logger.debug("change called %s", id)
-            self.browserList.getActive().setWorkingDir(id)
+            self.thread = threading.Thread(target=service.change,args=(id,))
+            self.thread.start()
         except KeyError as e:
             self.exceptionDisplayHandler.setException('KeyError','Passed id not in range: ' + repr(e))
         except TwitchException as e:
@@ -144,10 +156,13 @@ class WebController(TGController):
     '''    
     @expose()
     def searchFile(self, search):
-        self.__logger.debug("searchFile called")
-        #check if browser has search extension enabled, KEY ERROR
-        if(self.browserList.getActive().getDict()['browserSearch']==True):
-            self.browserList.getActive().setWorkingDir(search, search='File')
+        try:
+            self.thread = threading.Thread(target=service.search_file,args=(search,))
+            self.thread.start()
+        except Exception as e:
+            self.exceptionDisplayHandler.setException(
+                'Exception',
+                'Unhandled Exception in searchFile: ' + repr(e))
         redirect("/")
         
     '''
@@ -155,11 +170,13 @@ class WebController(TGController):
     '''
     @expose()
     def searchDir(self, search):
-        self.__logger.debug("searchDir called")
-        #check if browser has search extension enabled, KEY ERROR
-        if(self.browserList.getActive().getDict()['browserSearch']==True):
-            self.__logger.debug("browser Search enabled")
-            self.browserList.getActive().setWorkingDir(search, search='Dir')
+        try:
+            self.thread = threading.Thread(target=service.search_dir,args=(search,))
+            self.thread.start()
+        except Exception as e:
+            self.exceptionDisplayHandler.setException(
+                'Exception',
+                'Unhandled Exception in searchFile: ' + repr(e))
         redirect("/")
       
     '''
@@ -170,8 +187,7 @@ class WebController(TGController):
     def selectPlayer(self, id=None):
         try:
             id = self.parseID(id)
-            self.playerList.getActive().stop()
-            self.playerList.setActive(id)
+            service.select_player(id)
         except Exception as e:
             self.exceptionDisplayHandler.setException('Exception','Unhandled Exception in selectPlayer: ' + repr(e))
         redirect("/")
@@ -183,7 +199,7 @@ class WebController(TGController):
     def selectBrowser(self, id=None):
         try:
             id = self.parseID(id)
-            self.browserList.setActive(id)
+            service.select_browser(id)
         except Exception as e:
             self.exceptionDisplayHandler.setException('Exception','Unhandled Exception in selectBrowser: ' + repr(e))
         redirect("/")
@@ -195,7 +211,7 @@ class WebController(TGController):
     def selectPlaylist(self, id=None):
         try:
             id = self.parseID(id)
-            self.playlistList.setActive(id)
+            service.select_playlist(id)
         except Exception as e:
             self.exceptionDisplayHandler.setException('Exception','Unhandled Exception in selectPlaylist: ' + repr(e))
         redirect("/")
@@ -244,7 +260,7 @@ class WebInterface(Interface):
         self.config.serve_static = True
         self.config.paths['static_files'] = staticPath
         
-        #make wsgi_app      
+        #make wsgi_app
         self.application = self.config.make_wsgi_app()
         
         #make wsgi_server
@@ -262,5 +278,5 @@ class WebInterface(Interface):
     
     def shutdown(self):
         self.__logger.info("init shutdown")
-        self.controller.playerList.getActive().stop()
+        service.stop()
         self.keep_running=False
