@@ -8,7 +8,11 @@ class MPlayer(Omxplayer):
     
     keymapping = {
         'pause' : 'pause\n',
-        'quit'  : 'quit\n'
+        'quit'  : 'quit\n',
+        'volume': {
+                    'up'   : 'volume +5\n',
+                    'down' : 'volume -5\n'
+                  }
         }
 
     def __init__(self):
